@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2013, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -28,6 +28,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.TimeUnit;
 
 import com.mysql.fabric.FabricCommunicationException;
 import com.mysql.fabric.FabricStateResponse;
@@ -62,6 +63,7 @@ public class XmlRpcClient {
     private static final String METHOD_GROUP_LOOKUP_GROUPS = "group.lookup_groups";
     private static final String METHOD_GROUP_CREATE = "group.create";
     private static final String METHOD_GROUP_ADD = "group.add";
+    private static final String METHOD_GROUP_REMOVE = "group.remove";
     private static final String METHOD_GROUP_PROMOTE = "group.promote";
     private static final String METHOD_GROUP_DESTROY = "group.destroy";
     private static final String METHOD_THREAT_REPORT_ERROR = "threat.report_error";
@@ -98,7 +100,7 @@ public class XmlRpcClient {
     /**
      * Unmarshall a response representing a server.
      */
-    private static Server unmarshallServer(Map serverData) throws FabricCommunicationException {
+    private static Server unmarshallServer(Map<String, ?> serverData) throws FabricCommunicationException {
         ServerMode mode;
         ServerRole role;
 
@@ -131,9 +133,9 @@ public class XmlRpcClient {
     /**
      * Convert a list of string/string/bool to Server objects.
      */
-    private static Set<Server> toServerSet(List<Map> l) throws FabricCommunicationException {
+    private static Set<Server> toServerSet(List<Map<String, ?>> l) throws FabricCommunicationException {
         Set<Server> servers = new HashSet<Server>();
-        for (Map serverData : l) {
+        for (Map<String, ?> serverData : l) {
             servers.add(unmarshallServer(serverData));
         }
         return servers;
@@ -160,7 +162,7 @@ public class XmlRpcClient {
     public Set<String> getFabricNames() throws FabricCommunicationException {
         Response resp = errorSafeCallMethod(METHOD_DUMP_FABRIC_NODES, new Object[] {});
         Set<String> names = new HashSet<String>();
-        for (Map node : resp.getResultSet()) {
+        for (Map<String, ?> node : resp.getResultSet()) {
             names.add(node.get(FIELD_HOST) + ":" + node.get(FIELD_PORT));
         }
         return names;
@@ -171,7 +173,7 @@ public class XmlRpcClient {
      */
     public Set<String> getGroupNames() throws FabricCommunicationException {
         Set<String> groupNames = new HashSet<String>();
-        for (Map row : errorSafeCallMethod(METHOD_GROUP_LOOKUP_GROUPS, null).getResultSet()) {
+        for (Map<String, ?> row : errorSafeCallMethod(METHOD_GROUP_LOOKUP_GROUPS, null).getResultSet()) {
             groupNames.add((String) row.get(FIELD_GROUP_ID));
         }
         return groupNames;
@@ -198,7 +200,7 @@ public class XmlRpcClient {
         Response response = errorSafeCallMethod(METHOD_DUMP_SERVERS, new Object[] { version, groupPattern });
         // collect all servers by group name
         Map<String, Set<Server>> serversByGroupName = new HashMap<String, Set<Server>>();
-        for (Map server : response.getResultSet()) {
+        for (Map<String, ?> server : response.getResultSet()) {
             Server s = unmarshallServer(server);
             if (serversByGroupName.get(s.getGroupName()) == null) {
                 serversByGroupName.put(s.getGroupName(), new HashSet<Server>());
@@ -224,7 +226,7 @@ public class XmlRpcClient {
         Response tablesResponse = errorSafeCallMethod(METHOD_DUMP_SHARD_TABLES, args);
         Set<ShardTable> tables = new HashSet<ShardTable>();
         // construct the tables
-        for (Map rawTable : tablesResponse.getResultSet()) {
+        for (Map<String, ?> rawTable : tablesResponse.getResultSet()) {
             String database = (String) rawTable.get(FIELD_SCHEMA_NAME);
             String table = (String) rawTable.get(FIELD_TABLE_NAME);
             String column = (String) rawTable.get(FIELD_COLUMN_NAME);
@@ -241,7 +243,7 @@ public class XmlRpcClient {
         Set<ShardIndex> indices = new HashSet<ShardIndex>();
 
         // construct the index
-        for (Map rawIndexEntry : indexResponse.getResultSet()) {
+        for (Map<String, ?> rawIndexEntry : indexResponse.getResultSet()) {
             String bound = (String) rawIndexEntry.get(FIELD_LOWER_BOUND);
             int shardId = (Integer) rawIndexEntry.get(FIELD_SHARD_ID);
             String groupName = (String) rawIndexEntry.get(FIELD_GROUP_ID);
@@ -263,11 +265,12 @@ public class XmlRpcClient {
         Object args[] = new Object[] { version, shardMappingIdPattern }; // common to all calls
         Response mapsResponse = errorSafeCallMethod(METHOD_DUMP_SHARD_MAPS, args);
         // use the lowest ttl of all the calls
-        long minExpireTimeMillis = System.currentTimeMillis() + (1000 * mapsResponse.getTtl());
+        long minExpireTimeMillis = System.currentTimeMillis() + TimeUnit.SECONDS.toMillis(mapsResponse.getTtl());
+        int baseTtl = mapsResponse.getTtl();
 
         // construct the maps
         Set<ShardMapping> mappings = new HashSet<ShardMapping>();
-        for (Map rawMapping : mapsResponse.getResultSet()) {
+        for (Map<String, ?> rawMapping : mapsResponse.getResultSet()) {
             int mappingId = (Integer) rawMapping.get(FIELD_MAPPING_ID);
             ShardingType shardingType = ShardingType.valueOf((String) rawMapping.get(FIELD_TYPE_NAME));
             String globalGroupName = (String) rawMapping.get(FIELD_GLOBAL_GROUP_ID);
@@ -286,7 +289,7 @@ public class XmlRpcClient {
             mappings.add(m);
         }
 
-        return new FabricStateResponse<Set<ShardMapping>>(mappings, minExpireTimeMillis);
+        return new FabricStateResponse<Set<ShardMapping>>(mappings, baseTtl, minExpireTimeMillis);
     }
 
     public FabricStateResponse<Set<ShardMapping>> getShardMappings() throws FabricCommunicationException {
@@ -341,6 +344,10 @@ public class XmlRpcClient {
         errorSafeCallMethod(METHOD_GROUP_ADD, new Object[] { groupName, hostname + ":" + port });
     }
 
+    public void removeServerFromGroup(String groupName, String hostname, int port) throws FabricCommunicationException {
+        errorSafeCallMethod(METHOD_GROUP_REMOVE, new Object[] { groupName, hostname + ":" + port });
+    }
+
     public void promoteServerInGroup(String groupName, String hostname, int port) throws FabricCommunicationException {
         ServerGroup serverGroup = getServerGroup(groupName);
         for (Server s : serverGroup.getServers()) {
