@@ -1,10 +1,10 @@
 /*
-  Copyright (c) 2012, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2012, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -18,7 +18,7 @@
   You should have received a copy of the GNU General Public License along with this
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
- 
+
  */
 
 package com.mysql.jdbc;
@@ -28,8 +28,7 @@ import java.util.Properties;
 
 public interface CacheAdapterFactory<K, V> {
 
-	public abstract CacheAdapter<K, V> getInstance(Connection forConn, String url,
-			int cacheMaxSize, int maxKeySize, Properties connectionProperties)
-			throws SQLException;
+    public abstract CacheAdapter<K, V> getInstance(Connection forConn, String url, int cacheMaxSize, int maxKeySize, Properties connectionProperties)
+            throws SQLException;
 
 }
\ No newline at end of file
