@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -24,12 +24,14 @@
 package com.mysql.jdbc;
 
 import java.lang.reflect.Constructor;
+import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -57,7 +59,6 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
     protected Map<String, ConnectionImpl> liveConnections;
     private Map<String, Integer> hostsToListIndexMap;
     private Map<ConnectionImpl, String> connectionsToHostsMap;
-    private long activePhysicalConnections = 0;
     private long totalPhysicalConnections = 0;
     private long[] responseTimes;
 
@@ -68,7 +69,10 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
     public static final String BLACKLIST_TIMEOUT_PROPERTY_KEY = "loadBalanceBlacklistTimeout";
     private int globalBlacklistTimeout = 0;
     private static Map<String, Long> globalBlacklist = new HashMap<String, Long>();
-    private String hostToRemove = null;
+    public static final String HOST_REMOVAL_GRACE_PERIOD_PROPERTY_KEY = "loadBalanceHostRemovalGracePeriod";
+    private int hostRemovalGracePeriod = 0;
+    // host:port pairs to be considered as removed (definitely blacklisted) from the original hosts list.
+    private Set<String> hostsToRemove = new HashSet<String>();
 
     private boolean inTransaction = false;
     private long transactionStartTime = 0;
@@ -160,17 +164,28 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
             this.globalBlacklistTimeout = Integer.parseInt(blacklistTimeoutAsString);
         } catch (NumberFormatException nfe) {
             throw SQLError.createSQLException(
-                    Messages.getString("LoadBalancedConnectionProxy.badValueForLoadBalanceBlacklistTimeout", new Object[] { retriesAllDownAsString }),
+                    Messages.getString("LoadBalancedConnectionProxy.badValueForLoadBalanceBlacklistTimeout", new Object[] { blacklistTimeoutAsString }),
                     SQLError.SQL_STATE_ILLEGAL_ARGUMENT, null);
         }
 
+        String hostRemovalGracePeriodAsString = this.localProps.getProperty(HOST_REMOVAL_GRACE_PERIOD_PROPERTY_KEY, "15000");
+        try {
+            this.hostRemovalGracePeriod = Integer.parseInt(hostRemovalGracePeriodAsString);
+        } catch (NumberFormatException nfe) {
+            throw SQLError.createSQLException(Messages.getString("LoadBalancedConnectionProxy.badValueForLoadBalanceHostRemovalGracePeriod",
+                    new Object[] { hostRemovalGracePeriodAsString }), SQLError.SQL_STATE_ILLEGAL_ARGUMENT, null);
+        }
+
         String strategy = this.localProps.getProperty("loadBalanceStrategy", "random");
         if ("random".equals(strategy)) {
-            this.balancer = (BalanceStrategy) Util.loadExtensions(null, props, "com.mysql.jdbc.RandomBalanceStrategy", "InvalidLoadBalanceStrategy", null)
+            this.balancer = (BalanceStrategy) Util.loadExtensions(null, props, RandomBalanceStrategy.class.getName(), "InvalidLoadBalanceStrategy", null)
                     .get(0);
         } else if ("bestResponseTime".equals(strategy)) {
             this.balancer = (BalanceStrategy) Util
-                    .loadExtensions(null, props, "com.mysql.jdbc.BestResponseTimeBalanceStrategy", "InvalidLoadBalanceStrategy", null).get(0);
+                    .loadExtensions(null, props, BestResponseTimeBalanceStrategy.class.getName(), "InvalidLoadBalanceStrategy", null).get(0);
+        } else if ("serverAffinity".equals(strategy)) {
+            this.balancer = (BalanceStrategy) Util.loadExtensions(null, props, ServerAffinityStrategy.class.getName(), "InvalidLoadBalanceStrategy", null)
+                    .get(0);
         } else {
             this.balancer = (BalanceStrategy) Util.loadExtensions(null, props, strategy, "InvalidLoadBalanceStrategy", null).get(0);
         }
@@ -359,7 +374,6 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
         this.liveConnections.put(hostPortSpec, conn);
         this.connectionsToHostsMap.put(conn, hostPortSpec);
 
-        this.activePhysicalConnections++;
         this.totalPhysicalConnections++;
 
         return conn;
@@ -372,7 +386,6 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
         // close all underlying connections
         for (MySQLConnection c : this.liveConnections.values()) {
             try {
-                this.activePhysicalConnections--;
                 c.close();
             } catch (SQLException e) {
             }
@@ -405,7 +418,6 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
         // abort all underlying connections
         for (MySQLConnection c : this.liveConnections.values()) {
             try {
-                this.activePhysicalConnections--;
                 c.abortInternal();
             } catch (SQLException e) {
             }
@@ -430,7 +442,6 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
         // close all underlying connections
         for (MySQLConnection c : this.liveConnections.values()) {
             try {
-                this.activePhysicalConnections--;
                 c.abort(executor);
             } catch (SQLException e) {
             }
@@ -466,7 +477,7 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
             } else {
                 String reason = "No operations allowed after connection closed.";
                 if (this.closedReason != null) {
-                    reason += ("  " + this.closedReason);
+                    reason += " " + this.closedReason;
                 }
                 throw SQLError.createSQLException(reason, SQLError.SQL_STATE_CONNECTION_NOT_OPEN, null /* no access to a interceptor here... */);
             }
@@ -538,7 +549,6 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
                 }
                 foundHost = true;
             } catch (SQLException e) {
-                this.activePhysicalConnections--;
                 // give up if it is the current connection, otherwise NPE faking resultset later.
                 if (host.equals(this.connectionsToHostsMap.get(this.currentConnection))) {
                     // clean up underlying connections, since connection pool won't do it
@@ -604,7 +614,6 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
      */
     public void addToGlobalBlacklist(String host) {
         addToGlobalBlacklist(host, System.currentTimeMillis() + this.globalBlacklistTimeout);
-
     }
 
     /**
@@ -615,22 +624,21 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
     }
 
     /**
-     * Returns a local hosts blacklist, or a blacklist with a single host to be removed, while cleaning up expired records from the global blacklist.
+     * Returns a local hosts blacklist, while cleaning up expired records from the global blacklist, or a blacklist with the hosts to be removed.
      * 
      * @return
      *         A local hosts blacklist.
      */
     public synchronized Map<String, Long> getGlobalBlacklist() {
         if (!isGlobalBlacklistEnabled()) {
-            String localHostToRemove = this.hostToRemove;
-
-            if (this.hostToRemove != null) {
-                HashMap<String, Long> fakedBlacklist = new HashMap<String, Long>();
-                fakedBlacklist.put(localHostToRemove, System.currentTimeMillis() + 5000);
-                return fakedBlacklist;
+            if (this.hostsToRemove.isEmpty()) {
+                return new HashMap<String, Long>(1);
             }
-
-            return new HashMap<String, Long>(1);
+            HashMap<String, Long> fakedBlacklist = new HashMap<String, Long>();
+            for (String h : this.hostsToRemove) {
+                fakedBlacklist.put(h, System.currentTimeMillis() + 5000);
+            }
+            return fakedBlacklist;
         }
 
         // Make a local copy of the blacklist
@@ -670,24 +678,28 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
     /**
      * Removes a host from the host list, allowing it some time to be released gracefully if needed.
      * 
-     * @param host
+     * @param hostPortPair
      *            The host to be removed.
      * @throws SQLException
      */
-    public void removeHostWhenNotInUse(String host) throws SQLException {
-        int timeBetweenChecks = 1000;
-        long timeBeforeHardFail = 15000;
+    public void removeHostWhenNotInUse(String hostPortPair) throws SQLException {
+        if (this.hostRemovalGracePeriod <= 0) {
+            removeHost(hostPortPair);
+            return;
+        }
+
+        int timeBetweenChecks = this.hostRemovalGracePeriod > 1000 ? 1000 : this.hostRemovalGracePeriod;
 
         synchronized (this) {
-            addToGlobalBlacklist(host, System.currentTimeMillis() + timeBeforeHardFail + 1000);
+            addToGlobalBlacklist(hostPortPair, System.currentTimeMillis() + this.hostRemovalGracePeriod + timeBetweenChecks);
 
             long cur = System.currentTimeMillis();
 
-            while (System.currentTimeMillis() < cur + timeBeforeHardFail) {
-                this.hostToRemove = host;
+            while (System.currentTimeMillis() < cur + this.hostRemovalGracePeriod) {
+                this.hostsToRemove.add(hostPortPair);
 
-                if (!host.equals(this.currentConnection.getHost())) {
-                    removeHost(host);
+                if (!hostPortPair.equals(this.currentConnection.getHostPortPair())) {
+                    removeHost(hostPortPair);
                     return;
                 }
 
@@ -699,51 +711,55 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
             }
         }
 
-        removeHost(host);
+        removeHost(hostPortPair);
     }
 
     /**
      * Removes a host from the host list.
      * 
-     * @param host
+     * @param hostPortPair
      *            The host to be removed.
      * @throws SQLException
      */
-    public synchronized void removeHost(String host) throws SQLException {
+    public synchronized void removeHost(String hostPortPair) throws SQLException {
         if (this.connectionGroup != null) {
-            if (this.connectionGroup.getInitialHosts().size() == 1 && this.connectionGroup.getInitialHosts().contains(host)) {
+            if (this.connectionGroup.getInitialHosts().size() == 1 && this.connectionGroup.getInitialHosts().contains(hostPortPair)) {
                 throw SQLError.createSQLException("Cannot remove only configured host.", null);
             }
+        }
 
-            this.hostToRemove = host;
+        this.hostsToRemove.add(hostPortPair);
 
-            if (host.equals(this.currentConnection.getHost())) {
-                closeAllConnections();
-            } else {
-                this.connectionsToHostsMap.remove(this.liveConnections.remove(host));
-                Integer idx = this.hostsToListIndexMap.remove(host);
-                long[] newResponseTimes = new long[this.responseTimes.length - 1];
-                int newIdx = 0;
-                for (Iterator<String> i = this.hostList.iterator(); i.hasNext(); newIdx++) {
-                    String copyHost = i.next();
+        this.connectionsToHostsMap.remove(this.liveConnections.remove(hostPortPair));
+        if (this.hostsToListIndexMap.remove(hostPortPair) != null) {
+            long[] newResponseTimes = new long[this.responseTimes.length - 1];
+            int newIdx = 0;
+            for (String h : this.hostList) {
+                if (!this.hostsToRemove.contains(h)) {
+                    Integer idx = this.hostsToListIndexMap.get(h);
                     if (idx != null && idx < this.responseTimes.length) {
                         newResponseTimes[newIdx] = this.responseTimes[idx];
-                        this.hostsToListIndexMap.put(copyHost, newIdx);
                     }
+                    this.hostsToListIndexMap.put(h, newIdx++);
                 }
-                this.responseTimes = newResponseTimes;
             }
+            this.responseTimes = newResponseTimes;
+        }
+
+        if (hostPortPair.equals(this.currentConnection.getHostPortPair())) {
+            invalidateConnection(this.currentConnection);
+            pickNewConnection();
         }
     }
 
     /**
      * Adds a host to the hosts list.
      * 
-     * @param host
+     * @param hostPortPair
      *            The host to be added.
      */
-    public synchronized boolean addHost(String host) {
-        if (this.hostsToListIndexMap.containsKey(host)) {
+    public synchronized boolean addHost(String hostPortPair) {
+        if (this.hostsToListIndexMap.containsKey(hostPortPair)) {
             return false;
         }
 
@@ -751,8 +767,11 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
         System.arraycopy(this.responseTimes, 0, newResponseTimes, 0, this.responseTimes.length);
 
         this.responseTimes = newResponseTimes;
-        this.hostList.add(host);
-        this.hostsToListIndexMap.put(host, this.responseTimes.length - 1);
+        if (!this.hostList.contains(hostPortPair)) {
+            this.hostList.add(hostPortPair);
+        }
+        this.hostsToListIndexMap.put(hostPortPair, this.responseTimes.length - 1);
+        this.hostsToRemove.remove(hostPortPair);
 
         return true;
     }
@@ -766,7 +785,7 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
     }
 
     public synchronized long getActivePhysicalConnectionCount() {
-        return this.activePhysicalConnections;
+        return this.liveConnections.size();
     }
 
     public synchronized long getTotalPhysicalConnectionCount() {
@@ -794,4 +813,35 @@ public class LoadBalancedConnectionProxy extends MultiHostConnectionProxy implem
         }
         return 0;
     }
+
+    /**
+     * A LoadBalancedConnection proxy that provides null-functionality. It can be used as a replacement of the <code>null</null> keyword in the places where a
+     * LoadBalancedConnection object cannot be effectively <code>null</code> because that would be a potential source of NPEs.
+     */
+    private static class NullLoadBalancedConnectionProxy implements InvocationHandler {
+        public NullLoadBalancedConnectionProxy() {
+        }
+
+        public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
+            SQLException exceptionToThrow = SQLError.createSQLException(Messages.getString("LoadBalancedConnectionProxy.unusableConnection"),
+                    SQLError.SQL_STATE_INVALID_TRANSACTION_STATE, MysqlErrorNumbers.ERROR_CODE_NULL_LOAD_BALANCED_CONNECTION, true, null);
+            Class<?>[] declaredException = method.getExceptionTypes();
+            for (Class<?> declEx : declaredException) {
+                if (declEx.isAssignableFrom(exceptionToThrow.getClass())) {
+                    throw exceptionToThrow;
+                }
+            }
+            throw new IllegalStateException(exceptionToThrow.getMessage(), exceptionToThrow);
+        }
+    }
+
+    private static LoadBalancedConnection nullLBConnectionInstance = null;
+
+    static synchronized LoadBalancedConnection getNullLoadBalancedConnectionInstance() {
+        if (nullLBConnectionInstance == null) {
+            nullLBConnectionInstance = (LoadBalancedConnection) java.lang.reflect.Proxy.newProxyInstance(LoadBalancedConnection.class.getClassLoader(),
+                    INTERFACES_TO_PROXY, new NullLoadBalancedConnectionProxy());
+        }
+        return nullLBConnectionInstance;
+    }
 }
