@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -96,6 +96,11 @@ public abstract class MultiHostConnectionProxy implements InvocationHandler {
         }
 
         public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
+            if (METHOD_EQUALS.equals(method.getName())) {
+                // Let args[0] "unwrap" to its InvocationHandler if it is a proxy.
+                return args[0].equals(this);
+            }
+
             synchronized (MultiHostConnectionProxy.this) {
                 Object result = null;
 
@@ -452,6 +457,15 @@ public abstract class MultiHostConnectionProxy implements InvocationHandler {
             return invokeMore(proxy, method, args);
         } catch (InvocationTargetException e) {
             throw e.getCause() != null ? e.getCause() : e;
+        } catch (Exception e) {
+            // Check if the captured exception must be wrapped by an unchecked exception.
+            Class<?>[] declaredException = method.getExceptionTypes();
+            for (Class<?> declEx : declaredException) {
+                if (declEx.isAssignableFrom(e.getClass())) {
+                    throw e;
+                }
+            }
+            throw new IllegalStateException(e.getMessage(), e);
         }
     }
 
