@@ -429,6 +429,10 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         return getActiveMySQLConnection().getLoadBalanceStrategy();
     }
 
+    public String getServerAffinityOrder() {
+        return getActiveMySQLConnection().getServerAffinityOrder();
+    }
+
     public boolean getLoadBalanceValidateConnectionOnSwapServer() {
         return getActiveMySQLConnection().getLoadBalanceValidateConnectionOnSwapServer();
     }
@@ -1181,6 +1185,10 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         getActiveMySQLConnection().setLoadBalanceStrategy(strategy);
     }
 
+    public void setServerAffinityOrder(String hostsList) {
+        getActiveMySQLConnection().setServerAffinityOrder(hostsList);
+    }
+
     public void setLoadBalanceValidateConnectionOnSwapServer(boolean loadBalanceValidateConnectionOnSwapServer) {
         getActiveMySQLConnection().setLoadBalanceValidateConnectionOnSwapServer(loadBalanceValidateConnectionOnSwapServer);
     }
@@ -2471,6 +2479,14 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         getActiveMySQLConnection().setEnabledSSLCipherSuites(cipherSuites);
     }
 
+    public String getEnabledTLSProtocols() {
+        return getActiveMySQLConnection().getEnabledTLSProtocols();
+    }
+
+    public void setEnabledTLSProtocols(String protocols) {
+        getActiveMySQLConnection().setEnabledTLSProtocols(protocols);
+    }
+
     public boolean getEnableEscapeProcessing() {
         return getActiveMySQLConnection().getEnableEscapeProcessing();
     }
