@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2010, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2010, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -34,7 +34,7 @@ public class NdbLoadBalanceExceptionChecker extends StandardLoadBalanceException
 
     private boolean checkNdbException(SQLException ex) {
         // Have to parse the message since most NDB errors are mapped to the same DEMC, sadly.
-        return (ex.getMessage().startsWith("Lock wait timeout exceeded") || (ex.getMessage().startsWith("Got temporary error") && ex.getMessage().endsWith(
-                "from NDB")));
+        return (ex.getMessage().startsWith("Lock wait timeout exceeded")
+                || (ex.getMessage().startsWith("Got temporary error") && ex.getMessage().endsWith("from NDB")));
     }
 }
