@@ -101,9 +101,11 @@ public class NonRegisteringDriver implements java.sql.Driver {
     }
 
     static {
-        AbandonedConnectionCleanupThread referenceThread = new AbandonedConnectionCleanupThread();
-        referenceThread.setDaemon(true);
-        referenceThread.start();
+        try {
+            Class.forName(AbandonedConnectionCleanupThread.class.getName());
+        } catch (ClassNotFoundException e) {
+            // ignore
+        }
     }
 
     /**
@@ -194,7 +196,7 @@ public class NonRegisteringDriver implements java.sql.Driver {
 
         String[] splitValues = new String[2];
 
-        if (StringUtils.startsWithIgnoreCaseAndWs(hostPortPair, "address")) {
+        if (StringUtils.startsWithIgnoreCaseAndWs(hostPortPair, "address=")) {
             splitValues[HOST_NAME_INDEX] = hostPortPair.trim();
             splitValues[PORT_NUMBER_INDEX] = null;
 
