@@ -4,7 +4,7 @@
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -27,10 +27,9 @@ import java.sql.SQLException;
 
 class OperationNotSupportedException extends SQLException {
 
-	static final long serialVersionUID = 474918612056813430L;
+    static final long serialVersionUID = 474918612056813430L;
 
-	OperationNotSupportedException() {
-		super(
-				Messages.getString("RowDataDynamic.10"), SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
-	}
+    OperationNotSupportedException() {
+        super(Messages.getString("RowDataDynamic.10"), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+    }
 }
\ No newline at end of file
