@@ -1,10 +1,10 @@
 /*
-  Copyright (c) 2005, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2005, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -25,22 +25,23 @@ package com.mysql.jdbc.exceptions.jdbc4;
 
 import java.sql.SQLIntegrityConstraintViolationException;
 
-public class MySQLIntegrityConstraintViolationException extends
-		SQLIntegrityConstraintViolationException {
+public class MySQLIntegrityConstraintViolationException extends SQLIntegrityConstraintViolationException {
 
-	public MySQLIntegrityConstraintViolationException() {
-		super();
-	}
+    static final long serialVersionUID = -5528363270635808904L;
 
-	public MySQLIntegrityConstraintViolationException(String reason, String SQLState, int vendorCode) {
-		super(reason, SQLState, vendorCode);
-	}
+    public MySQLIntegrityConstraintViolationException() {
+        super();
+    }
 
-	public MySQLIntegrityConstraintViolationException(String reason, String SQLState) {
-		super(reason, SQLState);
-	}
+    public MySQLIntegrityConstraintViolationException(String reason, String SQLState, int vendorCode) {
+        super(reason, SQLState, vendorCode);
+    }
 
-	public MySQLIntegrityConstraintViolationException(String reason) {
-		super(reason);
-	}
+    public MySQLIntegrityConstraintViolationException(String reason, String SQLState) {
+        super(reason, SQLState);
+    }
+
+    public MySQLIntegrityConstraintViolationException(String reason) {
+        super(reason);
+    }
 }
