@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -55,8 +55,8 @@ public class CallableStatementWrapper extends PreparedStatementWrapper implement
             try {
                 String jdbc4ClassName = Util.isJdbc42() ? "com.mysql.jdbc.jdbc2.optional.JDBC42CallableStatementWrapper"
                         : "com.mysql.jdbc.jdbc2.optional.JDBC4CallableStatementWrapper";
-                JDBC_4_CALLABLE_STATEMENT_WRAPPER_CTOR = Class.forName(jdbc4ClassName).getConstructor(
-                        new Class[] { ConnectionWrapper.class, MysqlPooledConnection.class, CallableStatement.class });
+                JDBC_4_CALLABLE_STATEMENT_WRAPPER_CTOR = Class.forName(jdbc4ClassName)
+                        .getConstructor(new Class[] { ConnectionWrapper.class, MysqlPooledConnection.class, CallableStatement.class });
             } catch (SecurityException e) {
                 throw new RuntimeException(e);
             } catch (NoSuchMethodException e) {
@@ -272,11 +272,6 @@ public class CallableStatementWrapper extends PreparedStatementWrapper implement
         return 0;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.CallableStatement#getDouble(int)
-     */
     public double getDouble(int parameterIndex) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -291,11 +286,7 @@ public class CallableStatementWrapper extends PreparedStatementWrapper implement
         return 0;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.CallableStatement#getBigDecimal(int, int)
-     */
+    @Deprecated
     public BigDecimal getBigDecimal(int parameterIndex, int scale) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -329,11 +320,6 @@ public class CallableStatementWrapper extends PreparedStatementWrapper implement
         return null;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.CallableStatement#getDate(int)
-     */
     public Date getDate(int parameterIndex) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
