@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -43,8 +43,8 @@ public class StatementWrapper extends WrapperBase implements Statement {
     static {
         if (Util.isJdbc4()) {
             try {
-                JDBC_4_STATEMENT_WRAPPER_CTOR = Class.forName("com.mysql.jdbc.jdbc2.optional.JDBC4StatementWrapper").getConstructor(
-                        new Class[] { ConnectionWrapper.class, MysqlPooledConnection.class, Statement.class });
+                JDBC_4_STATEMENT_WRAPPER_CTOR = Class.forName("com.mysql.jdbc.jdbc2.optional.JDBC4StatementWrapper")
+                        .getConstructor(new Class[] { ConnectionWrapper.class, MysqlPooledConnection.class, Statement.class });
             } catch (SecurityException e) {
                 throw new RuntimeException(e);
             } catch (NoSuchMethodException e) {
@@ -75,11 +75,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         this.wrappedConn = c;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getConnection()
-     */
     public Connection getConnection() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -94,11 +89,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return null; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#setCursorName(java.lang.String)
-     */
     public void setCursorName(String name) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -111,11 +101,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#setEscapeProcessing(boolean)
-     */
     public void setEscapeProcessing(boolean enable) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -128,11 +113,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#setFetchDirection(int)
-     */
     public void setFetchDirection(int direction) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -145,11 +125,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getFetchDirection()
-     */
     public int getFetchDirection() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -164,11 +139,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return ResultSet.FETCH_FORWARD; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#setFetchSize(int)
-     */
     public void setFetchSize(int rows) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -181,11 +151,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getFetchSize()
-     */
     public int getFetchSize() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -200,11 +165,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return 0; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getGeneratedKeys()
-     */
     public ResultSet getGeneratedKeys() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -219,11 +179,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return null; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#setMaxFieldSize(int)
-     */
     public void setMaxFieldSize(int max) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -236,11 +191,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getMaxFieldSize()
-     */
     public int getMaxFieldSize() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -255,11 +205,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return 0; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#setMaxRows(int)
-     */
     public void setMaxRows(int max) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -272,11 +217,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getMaxRows()
-     */
     public int getMaxRows() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -291,11 +231,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return 0; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getMoreResults()
-     */
     public boolean getMoreResults() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -310,11 +245,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return false;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getMoreResults(int)
-     */
     public boolean getMoreResults(int current) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -329,11 +259,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return false;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#setQueryTimeout(int)
-     */
     public void setQueryTimeout(int seconds) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -346,11 +271,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getQueryTimeout()
-     */
     public int getQueryTimeout() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -365,11 +285,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return 0;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getResultSet()
-     */
     public ResultSet getResultSet() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -389,11 +304,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return null;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getResultSetConcurrency()
-     */
     public int getResultSetConcurrency() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -408,11 +318,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return 0;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getResultSetHoldability()
-     */
     public int getResultSetHoldability() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -427,11 +332,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return Statement.CLOSE_CURRENT_RESULT;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getResultSetType()
-     */
     public int getResultSetType() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -446,11 +346,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return ResultSet.TYPE_FORWARD_ONLY;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getUpdateCount()
-     */
     public int getUpdateCount() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -465,11 +360,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return -1;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#getWarnings()
-     */
     public SQLWarning getWarnings() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -484,11 +374,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return null;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#addBatch(java.lang.String)
-     */
     public void addBatch(String sql) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -499,11 +384,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#cancel()
-     */
     public void cancel() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -514,11 +394,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#clearBatch()
-     */
     public void clearBatch() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -529,11 +404,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#clearWarnings()
-     */
     public void clearWarnings() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -544,11 +414,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#close()
-     */
     public void close() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -562,11 +427,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#execute(java.lang.String, int)
-     */
     public boolean execute(String sql, int autoGeneratedKeys) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -581,11 +441,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return false; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#execute(java.lang.String, int[])
-     */
     public boolean execute(String sql, int[] columnIndexes) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -600,11 +455,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return false; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#execute(java.lang.String, java.lang.String[])
-     */
     public boolean execute(String sql, String[] columnNames) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -619,11 +469,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return false; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#execute(java.lang.String)
-     */
     public boolean execute(String sql) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -638,11 +483,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return false; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#executeBatch()
-     */
     public int[] executeBatch() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -657,34 +497,22 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return null; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#executeQuery(java.lang.String)
-     */
     public ResultSet executeQuery(String sql) throws SQLException {
+        ResultSet rs = null;
         try {
-            if (this.wrappedStmt != null) {
-
-                ResultSet rs = this.wrappedStmt.executeQuery(sql);
-                ((com.mysql.jdbc.ResultSetInternalMethods) rs).setWrapperStatement(this);
-
-                return rs;
+            if (this.wrappedStmt == null) {
+                throw SQLError.createSQLException("Statement already closed", SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
             }
+            rs = this.wrappedStmt.executeQuery(sql);
+            ((com.mysql.jdbc.ResultSetInternalMethods) rs).setWrapperStatement(this);
 
-            throw SQLError.createSQLException("Statement already closed", SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
         } catch (SQLException sqlEx) {
             checkAndFireConnectionError(sqlEx);
         }
 
-        return null; // we actually never get here, but the compiler can't figure that out
+        return rs;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#executeUpdate(java.lang.String, int)
-     */
     public int executeUpdate(String sql, int autoGeneratedKeys) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -699,11 +527,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return -1; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#executeUpdate(java.lang.String, int[])
-     */
     public int executeUpdate(String sql, int[] columnIndexes) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -718,12 +541,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return -1; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#executeUpdate(java.lang.String,
-     * java.lang.String[])
-     */
     public int executeUpdate(String sql, String[] columnNames) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -738,11 +555,6 @@ public class StatementWrapper extends WrapperBase implements Statement {
         return -1; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.Statement#executeUpdate(java.lang.String)
-     */
     public int executeUpdate(String sql) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
