@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2017, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -29,6 +29,7 @@ import java.sql.SQLException;
 
 import com.mysql.jdbc.ExceptionInterceptor;
 import com.mysql.jdbc.SQLError;
+import com.mysql.jdbc.Util;
 
 /**
  * Creates instances of loggers for the driver to use.
@@ -63,7 +64,7 @@ public class LogFactory {
             try {
                 loggerClass = Class.forName(className);
             } catch (ClassNotFoundException nfe) {
-                loggerClass = Class.forName(Log.class.getPackage().getName() + "." + className);
+                loggerClass = Class.forName(Util.getPackageName(Log.class) + "." + className);
             }
 
             Constructor<?> constructor = loggerClass.getConstructor(new Class[] { String.class });
