@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2014, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -49,7 +49,7 @@ public class Base64Decoder {
 
     private static byte getNextValidByte(byte[] in, IntWrapper pos, int maxPos) {
         while (pos.value <= maxPos) {
-            if (in[pos.value] <= 127 && decoderMap[in[pos.value]] >= 0) {
+            if (in[pos.value] >= 0 && decoderMap[in[pos.value]] >= 0) {
                 return in[pos.value++];
             }
             pos.value++;
