@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -62,6 +62,14 @@ public abstract class BaseTestCase extends TestCase {
 
     private final static String NO_MULTI_HOST_PROPERTY_NAME = "com.mysql.jdbc.testsuite.no-multi-hosts-tests";
 
+    // next variables disable some tests
+    protected boolean DISABLED_testBug15121 = true; // TODO needs to be fixed on server
+    protected boolean DISABLED_testBug7033 = true; // TODO disabled for unknown reason
+    protected boolean DISABLED_testBug2654 = true; // TODO check if it's still a server-level bug
+    protected boolean DISABLED_testBug5136 = true; // TODO disabled for unknown reason
+    protected boolean DISABLED_testBug65503 = true; // TODO disabled for unknown reason
+    protected boolean DISABLED_testContention = true; // TODO disabled for unknown reason
+
     /**
      * JDBC URL, initialized from com.mysql.jdbc.testsuite.url system property,
      * or defaults to jdbc:mysql:///test
@@ -840,11 +848,13 @@ public abstract class BaseTestCase extends TestCase {
             }
         });
 
-        for (int i = 0; i < possibleFiles.length; i++) {
-            try {
-                possibleFiles[i].delete();
-            } catch (Throwable t) {
-                // ignore, we're only making a best effort cleanup attempt here
+        if (possibleFiles != null) {
+            for (int i = 0; i < possibleFiles.length; i++) {
+                try {
+                    possibleFiles[i].delete();
+                } catch (Throwable t) {
+                    // ignore, we're only making a best effort cleanup attempt here
+                }
             }
         }
     }
@@ -913,36 +923,36 @@ public abstract class BaseTestCase extends TestCase {
     }
 
     protected static <EX extends Throwable> EX assertThrows(Class<EX> throwable, Callable<?> testRoutine) {
-        try {
-            testRoutine.call();
-        } catch (Throwable t) {
-            if (!throwable.isAssignableFrom(t.getClass())) {
-                fail("Expected exception of type '" + throwable.getName() + "' but instead a exception of type '" + t.getClass().getName() + "' was thrown.");
-            }
+        return assertThrows("", throwable, null, testRoutine);
+    }
 
-            return throwable.cast(t);
-        }
-        fail("Expected exception of type '" + throwable.getName() + "'.");
-
-        // never reaches here
-        return null;
+    protected static <EX extends Throwable> EX assertThrows(String message, Class<EX> throwable, Callable<?> testRoutine) {
+        return assertThrows(message, throwable, null, testRoutine);
     }
 
     protected static <EX extends Throwable> EX assertThrows(Class<EX> throwable, String msgMatchesRegex, Callable<?> testRoutine) {
+        return assertThrows("", throwable, msgMatchesRegex, testRoutine);
+    }
+
+    protected static <EX extends Throwable> EX assertThrows(String message, Class<EX> throwable, String msgMatchesRegex, Callable<?> testRoutine) {
+        if (message.length() > 0) {
+            message += " ";
+        }
         try {
             testRoutine.call();
         } catch (Throwable t) {
             if (!throwable.isAssignableFrom(t.getClass())) {
-                fail("Expected exception of type '" + throwable.getName() + "' but instead a exception of type '" + t.getClass().getName() + "' was thrown.");
+                fail(message + "expected exception of type '" + throwable.getName() + "' but instead a exception of type '" + t.getClass().getName()
+                        + "' was thrown.");
             }
 
-            if (!t.getMessage().matches(msgMatchesRegex)) {
-                fail("The error message «" + t.getMessage() + "» was expected to match «" + msgMatchesRegex + "».");
+            if (msgMatchesRegex != null && !t.getMessage().matches(msgMatchesRegex)) {
+                fail(message + "the error message «" + t.getMessage() + "» was expected to match «" + msgMatchesRegex + "».");
             }
 
             return throwable.cast(t);
         }
-        fail("Expected exception of type '" + throwable.getName() + "'.");
+        fail(message + "expected exception of type '" + throwable.getName() + "'.");
 
         // never reaches here
         return null;
@@ -1079,6 +1089,7 @@ public abstract class BaseTestCase extends TestCase {
             String port = parsedProps.getProperty(NonRegisteringDriver.PORT_PROPERTY_KEY, "3306");
             defaultHost = defaultHost + ":" + port;
         }
+        removeHostRelatedProps(parsedProps);
 
         if (customHost != null && customHost.length() > 0) {
             customHost = customHost + ",";
