@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2017, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -23,6 +23,8 @@
 
 package testsuite.perf;
 
+import com.mysql.jdbc.ConnectionImpl;
+
 import testsuite.BaseTestCase;
 
 /**
@@ -79,6 +81,9 @@ public class RetrievalPerfTest extends BaseTestCase {
      *             if an error occurs
      */
     public void testRetrievalCached() throws Exception {
+        if (!((ConnectionImpl) this.conn).isQueryCacheEnabled()) {
+            return;
+        }
         this.stmt.executeUpdate("SET QUERY_CACHE_TYPE = DEMAND");
 
         double fullBegin = System.currentTimeMillis();
