@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -70,7 +70,7 @@ public class StressRegressionTest extends BaseTestCase {
      * @throws Exception
      */
     public synchronized void testContention() throws Exception {
-        if (false) {
+        if (!this.DISABLED_testContention) {
             System.out.println("Calculating baseline elapsed time...");
 
             long start = System.currentTimeMillis();
@@ -132,14 +132,18 @@ public class StressRegressionTest extends BaseTestCase {
      * @throws Exception
      */
     public void testCreateConnections() throws Exception {
-        new CreateThread().start();
+        Thread t = new CreateThread();
+        t.start();
+        t.join();
     }
 
     /**
      * @throws Exception
      */
     public void testCreateConnectionsUnderLoad() throws Exception {
-        new CreateThread(new BusyThread()).start();
+        Thread t = new CreateThread(new BusyThread());
+        t.start();
+        t.join();
     }
 
     /**
@@ -189,7 +193,9 @@ public class StressRegressionTest extends BaseTestCase {
 
         @Override
         public void run() {
-            while (!this.stop) {
+            boolean doStop = this.stop;
+            while (!doStop) {
+                doStop = this.stop;
             }
         }
     }
@@ -264,6 +270,10 @@ public class StressRegressionTest extends BaseTestCase {
 
                 Properties nullProps = new Properties();
 
+                if (this.busyThread != null) {
+                    this.busyThread.start();
+                }
+
                 for (int i = 0; i < this.numConnections; i++) {
                     long startTime = System.currentTimeMillis();
                     connList[i] = getConnectionWithProps(nullProps);
@@ -339,8 +349,8 @@ public class StressRegressionTest extends BaseTestCase {
                         testPstmt.setTime(3, tm);
                         testPstmt.execute();
                     }
-                    System.out.println("Finishing job 1 (" + Thread.currentThread().getName() + ") after " + SharedInfoForTestBug67760.job1Iterations
-                            + " iterations...");
+                    System.out.println(
+                            "Finishing job 1 (" + Thread.currentThread().getName() + ") after " + SharedInfoForTestBug67760.job1Iterations + " iterations...");
                     testPstmt.close();
                 } catch (Exception e) {
                     e.printStackTrace();
@@ -368,8 +378,8 @@ public class StressRegressionTest extends BaseTestCase {
                         testRs.getTime(3);
                         testRs.close();
                     }
-                    System.out.println("Finishing job 2 (" + Thread.currentThread().getName() + ") after " + SharedInfoForTestBug67760.job2Iterations
-                            + " iterations...");
+                    System.out.println(
+                            "Finishing job 2 (" + Thread.currentThread().getName() + ") after " + SharedInfoForTestBug67760.job2Iterations + " iterations...");
                     testPstmt.close();
                 } catch (Exception e) {
                     e.printStackTrace();
