@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -32,11 +32,11 @@ import java.sql.SQLException;
 import java.sql.Types;
 import java.util.Properties;
 
-import testsuite.BaseTestCase;
-
 import com.mysql.jdbc.SQLError;
 import com.mysql.jdbc.log.StandardLogger;
 
+import testsuite.BaseTestCase;
+
 /**
  * Tests callable statement functionality.
  */
@@ -272,12 +272,12 @@ public class CallableStatementTest extends BaseTestCase {
 
         if (versionMeetsMinimum(5, 0)) {
 
-            @SuppressWarnings("unused")
             CallableStatement storedProc = null;
 
             createProcedure("testSpParse", "(IN FOO VARCHAR(15))\nBEGIN\nSELECT 1;\nend\n");
 
             storedProc = this.conn.prepareCall("{call testSpParse()}");
+            storedProc.close();
 
         }
     }
