@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2005, 2017, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -31,11 +31,11 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Properties;
 
-import testsuite.BaseTestCase;
-
 import com.mysql.jdbc.CharsetMapping;
 import com.mysql.jdbc.ConnectionImpl;
 
+import testsuite.BaseTestCase;
+
 public class ResultSetTest extends BaseTestCase {
 
     public ResultSetTest(String name) {
@@ -63,9 +63,10 @@ public class ResultSetTest extends BaseTestCase {
         // build map of charsets supported by server
         Connection c = getConnectionWithProps("detectCustomCollations=true");
         Map<String, Integer> charsetsMap = new HashMap<String, Integer>();
-        Iterator<Integer> collationIndexes = ((ConnectionImpl) c).indexToMysqlCharset.keySet().iterator();
-        while (collationIndexes.hasNext()) {
-            Integer index = collationIndexes.next();
+        this.rs = this.stmt.executeQuery("SHOW COLLATION");
+        while (this.rs.next()) {
+            int index = ((Number) this.rs.getObject(3)).intValue();
+
             String charsetName = null;
             if (((ConnectionImpl) c).indexToCustomMysqlCharset != null) {
                 charsetName = ((ConnectionImpl) c).indexToCustomMysqlCharset.get(index);
@@ -90,6 +91,7 @@ public class ResultSetTest extends BaseTestCase {
 
         while (charsetNames.hasNext()) {
             String charsetName = charsetNames.next();
+            System.out.println(charsetName);
 
             if (charsetName.equalsIgnoreCase("LATIN7") || charsetName.equalsIgnoreCase("BINARY")) {
                 continue; // no mapping in Java
@@ -129,8 +131,8 @@ public class ResultSetTest extends BaseTestCase {
 
         createTable("testPadding", "(" + columns.toString() + ", ord INT)");
 
-        this.stmt.executeUpdate("INSERT INTO testPadding VALUES (" + emptyBuf.toString() + ", 1), (" + abcBuf.toString() + ", 2), (" + repeatBuf.toString()
-                + ", 3)");
+        this.stmt.executeUpdate(
+                "INSERT INTO testPadding VALUES (" + emptyBuf.toString() + ", 1), (" + abcBuf.toString() + ", 2), (" + repeatBuf.toString() + ", 3)");
 
         try {
             Properties props = new Properties();
@@ -163,8 +165,8 @@ public class ResultSetTest extends BaseTestCase {
             for (int i = 0; i < numCols; i++) {
                 assertEquals(
                         "For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
-                                + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1), numChars, this.rs.getString(i + 1)
-                                .length());
+                                + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1),
+                        numChars, this.rs.getString(i + 1).length());
             }
         }
 
@@ -174,8 +176,8 @@ public class ResultSetTest extends BaseTestCase {
             for (int i = 0; i < numCols; i++) {
                 assertEquals(
                         "For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
-                                + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1), numChars, this.rs.getString(i + 1)
-                                .length());
+                                + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1),
+                        numChars, this.rs.getString(i + 1).length());
             }
         }
 
@@ -186,8 +188,8 @@ public class ResultSetTest extends BaseTestCase {
                 for (int i = 0; i < numCols; i++) {
                     assertEquals(
                             "For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
-                                    + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1), numChars,
-                            this.rs.getString(i + 1).length());
+                                    + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1),
+                            numChars, this.rs.getString(i + 1).length());
                 }
             }
         }
@@ -204,8 +206,8 @@ public class ResultSetTest extends BaseTestCase {
                 } else {
                     assertEquals(
                             "For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
-                                    + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1), numChars,
-                            this.rs.getString(i + 1).length());
+                                    + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1),
+                            numChars, this.rs.getString(i + 1).length());
                 }
             }
         }
@@ -222,8 +224,8 @@ public class ResultSetTest extends BaseTestCase {
                 } else {
                     assertEquals(
                             "For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
-                                    + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1), numChars,
-                            this.rs.getString(i + 1).length());
+                                    + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1),
+                            numChars, this.rs.getString(i + 1).length());
                 }
             }
         }
@@ -234,13 +236,15 @@ public class ResultSetTest extends BaseTestCase {
             while (this.rs.next()) {
                 for (int i = 0; i < numCols; i++) {
                     if (this.rs.getRow() != 3) {
-                        assertTrue("For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
-                                + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1), numChars != this.rs.getString(i + 1)
-                                .length());
+                        assertTrue(
+                                "For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
+                                        + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1),
+                                numChars != this.rs.getString(i + 1).length());
                     } else {
-                        assertEquals("For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
-                                + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1), numChars, this.rs.getString(i + 1)
-                                .length());
+                        assertEquals(
+                                "For column '" + this.rs.getMetaData().getColumnName(i + 1) + "' of collation "
+                                        + ((com.mysql.jdbc.ResultSetMetaData) this.rs.getMetaData()).getColumnCharacterSet(i + 1),
+                                numChars, this.rs.getString(i + 1).length());
                     }
                 }
             }
