@@ -4,7 +4,7 @@
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -28,18 +28,17 @@ import com.mysql.jdbc.profiler.ProfilerEvent;
 
 public class TestBug57662Logger extends StandardLogger {
 
-	public boolean hasNegativeDurations = false;
-	
-	public TestBug57662Logger(String name) {
-		super(name, false);
-	}
+    public boolean hasNegativeDurations = false;
 
-	@Override
-	protected void logInternal(int level, Object msg, Throwable exception) {
-		if (	!this.hasNegativeDurations &&
-				msg instanceof ProfilerEvent) {
-			this.hasNegativeDurations = ((ProfilerEvent) msg).getEventDuration() < 0;
-		}
-		super.logInternal(level, msg, exception);
-	}
+    public TestBug57662Logger(String name) {
+        super(name, false);
+    }
+
+    @Override
+    protected void logInternal(int level, Object msg, Throwable exception) {
+        if (!this.hasNegativeDurations && msg instanceof ProfilerEvent) {
+            this.hasNegativeDurations = ((ProfilerEvent) msg).getEventDuration() < 0;
+        }
+        super.logInternal(level, msg, exception);
+    }
 }
